Crate juper_swap_cpi

Crate juper_swap_cpi 

Modules

accounts
a lightweight crate that can be used both for Jupiter CPI, as well as for implementing, and using proxied jupiter swaps via AnyIx
instructions

Structs

SwapInputs
Wraps the input values for a given swap
V6SwapVerificationOpts

Enums

JupiterIx

Constants

JUPITER_AGG_IDS
JUPITER_V3_AGG_ID
the program id of the v3 jupiter aggregator
JUPITER_V6_AGG_ID
the program id of the v6 jupiter aggregator

Functions

decode_jupiter_instruction
Decodes the instruction data for a single instruction included within the transactions returned by jupiter’s swap api. The decoded instruction data is then parsed into the market the swap is being routed on, along with the swap input values
process_instructions
The reference implementation of the AnyIx instruction parser for use with the juper_swap_cpi crate. It performs basic access controls, ensuring the provided jupiter progrma account is the V3 aggregator, and that all input and output token accounts are owned by the wanted_toke_owner.
process_v6_swap
take_accounts_into_metas