Decodes the instruction data for a single instruction included within the transactions
returned by jupiter’s swap api. The decoded instruction data is then parsed into
the market the swap is being routed on, along with the swap input values
The reference implementation of the AnyIx instruction parser for use with
the juper_swap_cpi crate. It performs basic access controls, ensuring
the provided jupiter progrma account is the V3 aggregator, and that all
input and output token accounts are owned by the wanted_toke_owner.